@@ -39,10 +39,9 @@ def main(ip_str, deep_clean):
                 common.fatal(f"Cannot find DUT FuseSoC Core '{ip.dut_fsoc_full_name}'")
             clean_core(core)
         else:
-            vendor, name = common.parse_dep(ip.dut_name)
-            dut_ip = cache.get_ip(vendor, name)
+            dut_ip = cache.get_ip(ip.dut.vendor, ip.dut.target_ip)
             if dut_ip == None:
-                common.fatal(f"Cannot find DUT IP '{vendor}/{name}'")
+                common.fatal(f"Cannot find DUT IP '{ip.dut.vendor}/{ip.dut.target_ip}'")
             clean_ip(dut_ip)
 
 
