@@ -3,7 +3,7 @@
 ########################################################################################################################
 
 
-version = "1.0.9"
+version = "1.0.10"
 version_text = f"Moore.io CLI Client v{version}"
 
 
@@ -40,20 +40,20 @@ Full Command List (`mio help CMD` for help on a specific command):
       new            Creates new source code via the mio template engine
    
    IP and Credentials Management
-      install        Install all IP dependencies from IP Marketplace
-      login          Start session with IP Marketplace
-      package        Create a compressed (and potentially encrypted) archive of an IP
-      publish        Publish IP to IP Marketplace (must have mio admin account)
+      install        Installs all IP dependencies from IP Marketplace
+      login          Starts session with IP Marketplace
+      package        Creates a compressed (and potentially encrypted) archive of an IP
+      publish        Publishes IP to IP Marketplace (must have mio admin account)
    
    EDA Automation
-      !              Repeat last command
+      !              Repeats last command
       regr           Runs regression against an IP
       sim            Performs necessary steps to simulate an IP with any simulator
-      
+   
    Manage Results and other EDA Tool Outputs
       clean          Manages outputs from tools (other than job results)
       cov            Manages coverage data from EDA tools
-      dox            HDL source code documentation generation via Doxygen
+      dox            Generates HDL source code documentation via Doxygen
       results        Manages results from EDA tools
 """
 
