@@ -118,21 +118,16 @@ def install_ip_and_deps(vendor, name, global_install, username="", password=""):
         ip = cache.get_ip(vendor, name)
     if ip == None:
         common.banner(f"Installing IP '{vendor}/{name}'")
-        install_ip(vendor, name, global_install, username="", password="")
+        install_ip(vendor, name, global_install, username, password)
         cache.scan_and_load_ip_metadata()
         ip = cache.get_ip(vendor, name)
     
-    ip_list = []
-    for dep in ip.dependencies:
-        if dep.target_ip_model == None:
-            ip_str = f"{dep.vendor}/{dep.target_ip}"
-            ip_list.append(ip_str)
-        else:
-            if dep.target_ip_model.is_local == False:
-                ip_str = f"{dep.vendor}/{dep.target_ip}"
-                ip_list.append(ip_str)
-    common.info(f"Installing {len(ip_list)} dependencies")
-    install_ip_dep_list(ip, ip_list, global_install, username="", password="")
+    deps_to_install = ip.get_deps_to_install()
+    while len(deps_to_install) > 0:
+        common.info(f"Installing {len(deps_to_install)} dependencies")
+        install_ip_dep_list(ip, deps_to_install, global_install, username, password)
+        cache.scan_and_load_ip_metadata()
+        deps_to_install = ip.get_deps_to_install()
 
 
 def update_lock_file(ip, versions={}):
