@@ -161,7 +161,7 @@ def main(sim_job):
     create_sim_directories()
     
     check_dependencies(ip)
-    ip.update_is_compiled_elaborated(sim_job.simulator)
+    #ip.update_is_compiled_elaborated(sim_job.simulator)
     
     if sim_job.one_shot:
         one_step_sim(sim_job)
@@ -274,11 +274,11 @@ def multi_step_sim(sim_job):
                         est_time += curr_est_time
                     est_time = math.ceil(est_time / len(cfg.job_history[ip_str]['compilation']))
                     if est_time > 0:
-                        pool = ThreadPool(processes=1)
-                        pool.apply_async(progress_bar)
+                        #pool = ThreadPool(processes=1)
+                        #pool.apply_async(progress_bar)
                         cmp_target_ip(ip, sim_job)
-                        pool.terminate()
-                        pool.join()
+                        #pool.terminate()
+                        #pool.join()
                     else:
                         cmp_target_ip(ip, sim_job)
                 else:
@@ -307,11 +307,11 @@ def multi_step_sim(sim_job):
                     est_time += curr_est_time
                 est_time = math.ceil(est_time / len(cfg.job_history[ip_str]['elaboration']))
                 if est_time > 0:
-                    pool = ThreadPool(processes=1)
-                    pool.apply_async(progress_bar)
+                    #pool = ThreadPool(processes=1)
+                    #pool.apply_async(progress_bar)
                     eal.elaborate(ip, sim_job)
-                    pool.terminate()
-                    pool.join()
+                    #pool.terminate()
+                    #pool.join()
                 else:
                     eal.elaborate(ip, sim_job)
             else:
@@ -399,10 +399,7 @@ def bubble_wrap(sim_job):
                     if file in bwrap_ignore_dirs:
                         continue
                 common.dbg(f"Compressing {file}")
-                try:
-                    tar.add(file_path, filter=bwrap_exclude, arcname=file)
-                except TypeError:
-                    tar.add(file_path, exclude=bwrap_exclude, arcname=file)
+                tar.add(file_path, filter=bwrap_exclude, arcname=file)
         common.info("Done")
         
     except Exception as e:
@@ -410,10 +407,11 @@ def bubble_wrap(sim_job):
 
 
 
-def bwrap_exclude(filename):
+def bwrap_exclude(tar_info):
     for regex in bwrap_ignore_list:
-        if filename.endswith(regex):
-            return True
+        if tar_info.name.endswith(regex):
+            return None
+    return tar_info
 
 
 
@@ -612,6 +610,7 @@ def cmp_dependencies(ip, sim_job):
             dep_str = f"{dep.vendor}/{dep.name}"
             pbar.set_description(dep_str)
             eal.compile_ip(dep, sim_job)
+            pbar.update(1)
     #with alive_bar(num_deps, bar = 'smooth', stats="{eta} estimated", monitor=True, elapsed=True) as bar:
     #    for dep in deps_to_cmp:
     #        dep_str = f"{dep.vendor}/{dep.name}"
